@@ -996,6 +996,56 @@ def get_template(
         )
     )
 
+    template.add_resource(
+        codebuild.Project(
+            "BootstrapASpokeProject",
+            Name="servicecatalog-puppet-bootstrap-spoke",
+            ServiceRole=t.GetAtt("DeployRole", "Arn"),
+            Tags=t.Tags.from_dict(**{"ServiceCatalogPuppet:Actor": "Framework"}),
+            Artifacts=codebuild.Artifacts(Type="NO_ARTIFACTS"),
+            TimeoutInMinutes=60,
+            Environment=codebuild.Environment(
+                ComputeType="BUILD_GENERAL1_SMALL",
+                Image="aws/codebuild/standard:4.0",
+                Type="LINUX_CONTAINER",
+                EnvironmentVariables=[
+                    {
+                        "Type": "PLAINTEXT",
+                        "Name": "PUPPET_ACCOUNT_ID",
+                        "Value": t.Sub("${AWS::AccountId}"),
+                    },
+                    {
+                        "Type": "PLAINTEXT",
+                        "Name": "ORGANIZATION_ACCOUNT_ACCESS_ROLE_ARN",
+                        "Value": "CHANGE_ME",
+                    },
+                    {
+                        "Type": "PLAINTEXT",
+                        "Name": "ASSUMABLE_ROLE_IN_ROOT_ACCOUNT",
+                        "Value": "CHANGE_ME",
+                    },
+                ],
+            ),
+            Source=codebuild.Source(
+                BuildSpec=yaml.safe_dump(
+                    dict(
+                        version=0.2,
+                        phases=dict(
+                            install=install_spec,
+                            build={
+                                "commands": [
+                                    "servicecatalog-puppet bootstrap-spoke-as ${PUPPET_ACCOUNT_ID} ${ASSUMABLE_ROLE_IN_ROOT_ACCOUNT} ${ORGANIZATION_ACCOUNT_ACCESS_ROLE_ARN}"
+                                ]
+                            },
+                        ),
+                    )
+                ),
+                Type="NO_SOURCE",
+            ),
+            Description="Bootstrap given account as a spoke",
+        )
+    )
+
     cloud_formation_events_queue = template.add_resource(
         sqs.Queue(
             "CloudFormationEventsQueue",
